( cd usr/lib ; rm -rf libhamlib.so )
( cd usr/lib ; ln -sf libhamlib-1.2.4.so.2.0.3 libhamlib.so )
( cd usr/lib ; rm -rf libhamlib-1.2.4.so.2 )
( cd usr/lib ; ln -sf libhamlib-1.2.4.so.2.0.3 libhamlib-1.2.4.so.2 )
( cd usr/lib ; rm -rf libhamlib++-1.2.4.so.2 )
( cd usr/lib ; ln -sf libhamlib++-1.2.4.so.2.0.0 libhamlib++-1.2.4.so.2 )
( cd usr/lib ; rm -rf libhamlib++.so )
( cd usr/lib ; ln -sf libhamlib++-1.2.4.so.2.0.0 libhamlib++.so )
